@@ -15,7 +15,8 @@ file_path <- system.file("extdata", "example-1.csv", package = "plater")
    
 data <- read_plate(
       file = file_path,             # full path to the .csv file
-      well_ids_column = "Wells"     # name to give column of well IDs (optional)
+      well_ids_column = "Wells",    # name to give column of well IDs (optional)
+      sep = ","                     # separator used in the csv file (optional)
 )
 str(data)
 
@@ -33,7 +34,8 @@ meta <- system.file("extdata", "example-2-part-B.csv", package = "plater")
 data2 <- add_plate(
       data = data2,               # data frame to add to 
       file = meta,                # full path to the .csv file
-      well_ids_column = "Wells"   # name of column of well IDs in data frame
+      well_ids_column = "Wells",   # name of column of well IDs in data frame
+      sep = ","                   # separator used in the csv file (optional)
 )
 
 str(data2)
@@ -50,7 +52,8 @@ file2 <- system.file("extdata", "more-bacteria.csv", package = "plater")
 data <- read_plates(
    files = c(file1, file2),
    plate_names = c("Experiment 1", "Experiment 2"),
-   well_ids_column = "Wells") # optional
+   well_ids_column = "Wells", # optional
+   sep = ",")                 # optional
 
 str(data)
 
